summaryrefslogtreecommitdiff
path: root/lib/chef/api_client/registration.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/chef/api_client/registration.rb')
-rw-r--r--lib/chef/api_client/registration.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/chef/api_client/registration.rb b/lib/chef/api_client/registration.rb
index bc941d5bfa..99667acc0a 100644
--- a/lib/chef/api_client/registration.rb
+++ b/lib/chef/api_client/registration.rb
@@ -17,7 +17,7 @@
#
require 'chef/config'
-require 'chef/rest'
+require 'chef/server_api'
require 'chef/exceptions'
class Chef
@@ -45,7 +45,7 @@ class Chef
#--
# If client creation fails with a 5xx, it is retried up to 5 times. These
# retries are on top of the retries with randomized exponential backoff
# built in to Chef::REST. The retries here are a workaround for failures
# caused by resource contention in Hosted Chef when creating a very large
# number of clients simultaneously, (e.g., spinning up 100s of ec2 nodes
# at once). Future improvements to the affected component should make
@@ -45,7 +45,7 @@ class Chef
# If client creation fails with a 5xx, it is retried up to 5 times. These
# retries are on top of the retries with randomized exponential backoff
- # built in to Chef::REST. The retries here are a workaround for failures
+ # built in to Chef::ServerAPI. The retries here are a workaround for failures
# caused by resource contention in Hosted Chef when creating a very large
# number of clients simultaneously, (e.g., spinning up 100s of ec2 nodes